@@ -67,7 +67,7 @@ Handel::Exception - Exceptions used within Handel
 
 =head1 VERSION
 
-    $Id: Exception.pm 29 2004-12-31 02:10:21Z claco $
+    $Id: Exception.pm 53 2004-12-31 23:13:51Z claco $
 
 =head1 SYNOPSIS
 
@@ -83,14 +83,14 @@ Handel::Exception - Exceptions used within Handel
     } catch Handel::Exception with {
         print 'Unknown issue with Handel';
     } catch Error with {
-        print 'Unhandeled exception';
+        print 'Unhandled exception';
     } otherwise {
         print 'aliens ate my exception';
     };
 
 =head1 DESCRIPTION
 
-C<Handel::Exception> subclasses L<Error> and attemps to throw exceptions when
+C<Handel::Exception> subclasses L<Error> and attempts to throw exceptions when
 unexpected things happen.
 
 =head1 EXCEPTIONS
@@ -98,17 +98,17 @@ unexpected things happen.
 =head2 C<Handel::Exception>
 
 This is the base exception thrown in C<Handel>. All other exceptions subclass
-C<Handel::Exception> so it's possibly to catch all Hendel generated exceptions
+C<Handel::Exception> so it's possibly to catch all Handel generated exceptions
 with a single C<catch> statement.
 
     try {
         ...
     } catch Handel::Exception with {
         my $E = shift;
-        print 'Something bad happend in Handel: ' . E->text;
+        print 'Something bad happened in Handel: ' . E->text;
 
     } catch MyApplicaitonException with {
-        print 'Something bad happend in MyApplication';
+        print 'Something bad happened in MyApplication';
 
     };
 
@@ -119,7 +119,7 @@ exceptions.
 
 This exception is thrown if a database constraint is violated. This is true for
 both raw DBI database constraint errors as well as  field updates that don't
-pass constaints in C<Handel::Constraints>.
+pass constraints in C<Handel::Constraints>.
 
 =head2 C<Handel::Exception::Argument>
 
